{
rails: {
error: {
generic: "Error",
},
gem: {
checking_installation_path: "Checking path %s for gem %s",
installed: "Installed %s gem",
installed_debug: "%s installed: %s",
installing: "Installing %s gem...",
setting_gem_home: "GEM_HOME being set to %s",
setting_gem_path: "GEM_PATH being set to %s",
},
create: {
help: <<~HELP,
error: {
invalid_ruby_version: <<~MSG,
dir_exists: "Project directory %s already exists. Please use a different name.",
install_failure: "Error installing %s gem",
node_required: "node is required to create a rails project. Download at https://nodejs.org/en/download.",
node_version_failure: "Failed to get the current node version. Please make sure it is installed as " \
"per the instructions at https://nodejs.org/en.",
yarn_required: "yarn is required to create a rails project. Download at " \
"https://classic.yarnpkg.com/en/docs/install.",
yarn_version_failure: "Failed to get the current yarn version. Please make sure it is installed as per " \
"the instructions at https://classic.yarnpkg.com/en/docs/install.",
},
info: {
created: "{{v}} {{green:%s}} was created in your Partner Dashboard {{underline:%s}}",
serve: "{{*}} Change directories to your new project folder {{green:%s}} and run {{command:%s serve}} " \
"to start a local server",
install: "{{*}} Then, visit {{underline:%s/test}} to install {{green:%s}} on your Dev Store",
open_new_shell: "{{*}} {{yellow:After installing %s, please open a new Command Prompt or PowerShell " \
"window to continue.}}",
},
installing_bundler: "Installing bundler...",
generating_app: "Generating new rails app project in %s...",
adding_shopify_gem: "{{v}} Adding shopify_app gem...",
node_version: "node %s",
yarn_version: "yarn %s",
running_bundle_install: "Running bundle install...",
running_generator: "Running shopify_app generator...",
running_migrations: "Running migrations...",
running_webpacker_install: "Running webpacker:install...",
},
deploy: {
help: <<~HELP,
extended_help: <<~HELP,
heroku: {
help: <<~HELP,
downloading: "Downloading Heroku CLI...",
downloaded: "Downloaded Heroku CLI",
installing: "Installing Heroku CLI...",
installed: "Installed Heroku CLI",
authenticated_with_account: "{{v}} Authenticated with Heroku as `%s`",
authenticating: "Authenticating with Heroku...",
authenticated: "{{v}} Authenticated with Heroku",
deploying: "Deploying to Heroku...",
deployed: "{{v}} Deployed to Heroku",
db_check: {
validating: "Validating application...",
checking: "Checking database type...",
validated: "Database type \"%s\" validated for platform \"Heroku\"",
problem: "A problem was encountered while checking your database type.",
sqlite: <<~SQLITE,
},
git: {
checking: "Checking git repo...",
initialized: "Git repo initialized",
what_branch: "What branch would you like to deploy?",
branch_selected: "{{v}} Git branch `%s` selected for deploy",
},
app: {
no_apps_found: "No existing Heroku app found. What would you like to do?",
name: "What is your Heroku app’s name?",
select: "Specify an existing Heroku app",
selecting: "Selecting Heroku app `%s`...",
selected: "{{v}} Heroku app `%s` selected",
create: "Create a new Heroku app",
creating: "Creating new Heroku app...",
created: "{{v}} New Heroku app created",
},
},
},
generate: {
help: <<~HELP,
extended_help: <<~EXAMPLES,
error: {
name_exists: "%s already exists!",
generic: "Error generating %s",
},
webhook: {
help: <<~HELP,
select: "What type of webhook would you like to create?",
selected: "Generating webhook: %s",
},
},
open: {
help: <<~HELP,
},
populate: {
help: <<~HELP,
extended_help: <<~HELP,
customer: {
added: "%s added to {{green:%s}} at {{underline:%scustomers/%d}}",
},
draft_order: {
added: "DraftOrder added to {{green:%s}} at {{underline:%sdraft_orders/%d}}",
},
product: {
added: "%s added to {{green:%s}} at {{underline:%sproducts/%d}}",
},
},
serve: {
help: <<~HELP,
extended_help: <<~HELP,
error: {
host_must_be_https: "{{red:HOST must be a HTTPS url.}}",
},
open_info: <<~MESSAGE,
running_server: "Running server...",
},
tunnel: {
help: <<~HELP,
extended_help: <<~HELP,
error: {
token_argument_missing: "{{x}} {{red:auth requires a token argument}}\n\n",
},
},
forms: {
create: {
error: {
invalid_app_type: "Invalid app type %s",
invalid_db_type: "Invalid database type %s",
},
app_name: "App name",
app_type: {
select: "What type of app are you building?",
select_public: "Public: An app built for a wide merchant audience.",
select_custom: "Custom: An app custom built for a single client.",
selected: "App type {{green:%s}}",
},
db: {
want_select: <<~WANT_SELECT,
select: "What database type would you like to use? Please ensure the database is installed.",
select_sqlite3: "SQLite (default)",
select_mysql: "MySQL",
select_postgresql: "PostgreSQL",
select_oracle: "Oracle",
select_frontbase: "FrontBase",
select_ibm_db: "IBM_DB",
select_sqlserver: "SQL Server",
select_jdbcmysql: "JDBC MySQL",
select_jdbcsqlite3: "JDBC SQlite",
select_jdbcpostgresql: "JDBC PostgreSQL",
select_jdbc: "JDBC",
selected: "Database Type {{green:%s}}",
},
},
},
},
}.freeze